The Styleguide section has been moved to the Wireshark Developer's Guide.
[obnox/wireshark/wip.git] / color.h
diff --git a/color.h b/color.h
index 043f3b07d80d12382e73edeaa7ffccbef2f228db..622b6ab7f1a28d42b11bf8cdf7dbf7107891d63b 100644 (file)
--- a/color.h
+++ b/color.h
@@ -3,8 +3,8 @@
  *
  * $Id$
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
@@ -25,8 +25,6 @@
 #ifndef __COLOR_H__
 #define __COLOR_H__
 
-#include "epan/dfilter/dfilter.h"
-
 /*
  * Data structure holding RGB value for a color.
  *
@@ -43,42 +41,15 @@ typedef struct {
        guint16 blue;
 } color_t;
 
/** Create a color from R, G, and B values, and do whatever toolkit-dependent
** work needs to be done.
  *
  * @param color the color_t to be filled
  * @param red the red value for the color
  * @param green the green value for the color
  * @param blue the blue value for the color
- * @param source the GdkColor to be filled
  * @return TRUE if it succeeds, FALSE if it fails
  */
-gboolean create_color(color_t *color, guint16 red, guint16 green, guint16 blue);
-
-/* Data for a color filter. */
-typedef struct _color_filter {
-        gchar     *filter_name;   /* name of the filter */
-        gchar     *filter_text;   /* text of the filter expression */
-        color_t    bg_color;      /* background color for packets that match */
-        color_t    fg_color;      /* foreground color for packets that match */
-        dfilter_t *c_colorfilter; /* compiled filter expression */
-        void      *edit_dialog;   /* if filter is being edited, dialog
-                                   * box for it */
-       gboolean    marked;         /* set if the filter is marked in the color dialog box */
-} color_filter_t;
-
-/* List of all color filters. */
-extern GSList *filter_list;
-extern GSList *removed_filter_list;
-
-/** Add a color filter.
- *
- * @param colorf the new color filter
- * @param arg the color filter widget
- */
-void color_add_filter_cb (color_filter_t *colorf, gpointer arg);
-
-void
-filter_list_prime_edt(epan_dissect_t *edt);
+gboolean initialize_color(color_t *color, guint16 red, guint16 green, guint16 blue);
 
 #endif
@@ -43,42 +41,15 @@ typedef struct {
 } color_t;
 
-/** Create a color from R, G, and B values, and do whatever toolkit-dependent
- ** work needs to be done.
+/** Initialize a color with R, G, and B values, including any toolkit-dependent
+ ** work that needs to be done.
  *
  * @param color the color_t to be filled